# Conference Rooms
This is a list of every conference room in the database where you can modify, delete and add new rooms. Typing in the search field filters the conference rooms by name.

## Columns:
Each column has a triangle on the right. Click on the triangle to show filter options for that column. Click on the arrows next to the column name to order by that column in ascending or descending order. Hold shift while clicking to order multiple columns with individual weight.

### Name:
The name of the room.

### E-Mail-Address:
The room's email address. Must be unique.

### Building:
The building in which the room is located. You can add buildings under CRM > Administration > Conference Room > Buildings.

### Capacity:
The maximum amount of people that can be seated in the room. Is used to warn users when they add too many participants to a conference room meeting.

### Capable of Videoconferencing:
Indicates if a conference room is equipped to take part in a video conference. If it is not, participants won't be able to set their attendance as "Attend Digitally".
